@@ -21,6 +21,10 @@ str(tpesq)
 tpublic <- l.out$tpublic
 str(tpublic)
 
+## ------------------------------------------------------------------------
+tsupervisions <- l.out$tsupervisions
+str(tsupervisions)
+
 ## ------------------------------------------------------------------------
 library(ggplot2)
 
